{% extends 'admin/change_list.html' %}
{% load i18n %}
{% load admin_list %}

{% block search %}{% endblock %}

{% block filters %}
  {% if cl.has_filters %}
    <div id="changelist-filter">
      <h2>{% trans 'Filter' %}</h2>
    <form method="get">
      {% for spec in cl.filter_specs %}{% admin_list_filter cl spec %}{% endfor %}
    <input type="submit">
    </form>
    </div>
  {% endif %}
{% endblock %}
